==> typolight-2.6.2.tar.gz: typolight-2.6.2/system/modules/rep_client/languages/en/tl_repository.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');
/**
 * TYPOlight Repository :: Language file for backend module (en)
 *
 * NOTE: this file was edited with tabs set to 4.
 * @package Repository
 * @copyright Copyright (C) 2008 by Acenes. See accompaning file LICENSE.txt for license conditions and author contact information.
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 */
 
/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_repository']['lickey']        = array('License key', 'Enter the license key that you got from the extension vendor.');
$GLOBALS['TL_LANG']['tl_repository']['uninstprotect'] = array('Uninstall protection', 'Protect extension against accidental uninstallation.');

/**
 * References
 */
$GLOBALS['TL_LANG']['tl_repository']['action']             = 'Action';
$GLOBALS['TL_LANG']['tl_repository']['actionsummary']      = 'Action summary';
$GLOBALS['TL_LANG']['tl_repository']['actionsuccess']      = 'Actions successful.';
$GLOBALS['TL_LANG']['tl_repository']['actionfailed']       = 'One or more actions failed.';
$GLOBALS['TL_LANG']['tl_repository']['apply']              = 'Apply';
$GLOBALS['TL_LANG']['tl_repository']['byorder']            = 'By %s';
$GLOBALS['TL_LANG']['tl_repository']['checkextension']     = 'Check extension';
$GLOBALS['TL_LANG']['tl_repository']['dbuptodate']         = 'Database is up to date';
$GLOBALS['TL_LANG']['tl_repository']['deletingdirs']       = 'Deleting directories'; 
$GLOBALS['TL_LANG']['tl_repository']['deletingfiles']      = 'Deleting files'; 
$GLOBALS['TL_LANG']['tl_repository']['editextension']      = 'Edit settings';
$GLOBALS['TL_LANG']['tl_repository']['extinstrecntf']      = 'Extension install record not found';
$GLOBALS['TL_LANG']['tl_repository']['errdldpkg']          = 'Download of package from repository failed';
$GLOBALS['TL_LANG']['tl_repository']['failed']             = 'failed';
$GLOBALS['TL_LANG']['tl_repository']['fileerrwrite']       = 'Error writing file %s';
$GLOBALS['TL_LANG']['tl_repository']['filesdeleted']       = '%s file(s) deleted'; 
$GLOBALS['TL_LANG']['tl_repository']['filesinstalled']     = '%s file(s) installed';
$GLOBALS['TL_LANG']['tl_repository']['filesunchanged']     = '%s file(s) unchanged'; 
$GLOBALS['TL_LANG']['tl_repository']['filesupdated']       = '%s file(s) updated'; 
$GLOBALS['TL_LANG']['tl_repository']['goback']             = 'Go back';
$GLOBALS['TL_LANG']['tl_repository']['install']            = 'Install';
$GLOBALS['TL_LANG']['tl_repository']['installextension']   = 'Install/update extension';
$GLOBALS['TL_LANG']['tl_repository']['installingext']      = 'Install %s %s build %s';
$GLOBALS['TL_LANG']['tl_repository']['installlogtitle']    = 'File installation/update log';
$GLOBALS['TL_LANG']['tl_repository']['lickeyrequired']     = 'This extension requires a license key. Please visit the vendor\'s shop to purchase one.';
$GLOBALS['TL_LANG']['tl_repository']['none']               = 'None';
$GLOBALS['TL_LANG']['tl_repository']['notfound']           = 'not found';
$GLOBALS['TL_LANG']['tl_repository']['ok']                 = 'OK';
$GLOBALS['TL_LANG']['tl_repository']['okuninstextension']  = 'OK to uninstall <em>%s</em> now?';
$GLOBALS['TL_LANG']['tl_repository']['showdetails']        = 'Show details';
$GLOBALS['TL_LANG']['tl_repository']['stateshint']         = 'Check the states to be included.';
$GLOBALS['TL_LANG']['tl_repository']['status']             = 'Status';
$GLOBALS['TL_LANG']['tl_repository']['success']            = 'success';
$GLOBALS['TL_LANG']['tl_repository']['uninstallextension'] = 'Uninstall extension';
$GLOBALS['TL_LANG']['tl_repository']['updatedatabase']     = 'Check/update database';
$GLOBALS['TL_LANG']['tl_repository']['updateextension']    = 'Update extension';
$GLOBALS['TL_LANG']['tl_repository']['update']             = 'Update';
$GLOBALS['TL_LANG']['tl_repository']['updates']            = 'Updates';
$GLOBALS['TL_LANG']['tl_repository']['updatehint']         = 'Check the states to be included at updates.';
$GLOBALS['TL_LANG']['tl_repository']['updatingext']        = 'Update %s %s build %s';
$GLOBALS['TL_LANG']['tl_repository']['validate']           = 'Repair';
$GLOBALS['TL_LANG']['tl_repository']['validatingext']      = 'Verify/repair %s %s build %s';

/**
 * Status messages
 */
$GLOBALS['TL_LANG']['tl_repository']['statext']['uptodate']        = 'Up to date.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['notapproved']     = 'Not approved for %s %s.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['notapprovedwith'] = 'Not approved with %s %s.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['newversion']      = 'New version %s build %s available.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['depmissing']      = 'Missing required extension %s.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['extnotfound']     = 'Extension not found in repository.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['vernotfound']     = 'Installed version not found in repository.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['extneedkey']      = 'License key required, install extension in advance.';
$GLOBALS['TL_LANG']['tl_repository']['statext']['errorinstall']    = 'Failed installation, update/repair adviced.';

?>

==> typolight-2.6.7.tar.gz: typolight-2.6.7/system/modules/rep_client/languages/en/tl_repository.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');
/**
 * TYPOlight Repository :: Language file for backend module (en)
 *
 * NOTE: this file was edited with tabs set to 4.
 * @package Repository
 * @copyright Copyright (C) 2008 by Acenes. See accompaning file LICENSE.txt for license conditions and author contact information.
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 */
 
/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_repository']['lickey']        = array('License key', 'Enter the license key that you got from the extension vendor.');
$GLOBALS['TL_LANG']['tl_repository']['uninstprotect'] = array('Uninstall protection', 'Protect extension against accidental uninstallation.');

/**
 * References
 */
$GLOBALS['TL_LANG']['tl_repository']['action']             = 'Action';
$GLOBALS['TL_LANG']['tl_repository']['actionsummary']      = 'Action summary';
$GLOBALS['TL_LANG']['tl_repository']['actionsuccess']      = 'Actions successful.';
$GLOBALS['TL_LANG']['tl_repository']['actionfailed']       = 'One or more actions failed.';
$GLOBALS['TL_LANG']['tl_repository']['apply']              = 'Apply';
$GLOBALS['TL_LANG']['tl_repository']['byorder']            = 'By %s';
$GLOBALS['TL_LANG']['tl_repository']['checkextension']     = 'Check extension';
$GLOBALS['TL_LANG']['tl_repository']['dbuptodate']         = 'Database is up to date';
$GLOBALS['TL_LANG']['tl_repository']['deletingdirs']       = 'Deleting directories'; 
$GLOBALS['TL_LANG']['tl_repository']['deletingfiles']      = 'Deleting files'; 
$GLOBALS['TL_LANG']['tl_repository']['editextension']      = 'Edit settings';
$GLOBALS['TL_LANG']['tl_repository']['extinstrecntf']      = 'Extension install record not found';
$GLOBALS['TL_LANG']['tl_repository']['errdldpkg']          = 'Download of package from repository failed';
$GLOBALS['TL_LANG']['tl_repository']['failed']             = 'failed';
$GLOBALS['TL_LANG']['tl_repository']['fileerrwrite']       = 'Error writing file %s';
$GLOBALS['TL_LANG']['tl_repository']['filesdeleted']       = '%s file(s) deleted'; 
$GLOBALS['TL_LANG']['tl_repository']['filesinstalled']     = '%s file(s) installed';
$GLOBALS['TL_LANG']['tl_repository']['filesunchanged']     = '%s file(s) unchanged'; 
$GLOBALS['TL_LANG']['tl_repository']['filesupdated']       = '%s file(s) updated'; 
$GLOBALS['TL_LANG']['tl_repository']['goback']             = 'Go back';
$GLOBALS['TL_LANG']['tl_repository']['install']            = 'Install';
$GLOBALS['TL_LANG']['tl_repository']['installextension']   = 'Install/update extension';
$GLOBALS['TL_LANG']['tl_repository']['installingext']      = 'Install %s %s build %s';
$GLOBALS['TL_LANG']['tl_repository']['installlogtitle']    = 'File installation/update log';
$GLOBALS['TL_LANG']['tl_repository']['lickeyrequired']     = 'This extension requires a license key. Please visit the vendor\'s shop to purchase one.';
$GLOBALS['TL_LANG']['tl_repository']['none']               = 'None';
$GLOBALS['TL_LANG']['tl_repository']['notfound']           = 'not found';
$GLOBALS['TL_LANG']['tl_repository']['ok']                 = 'OK';
$GLOBALS['TL_LANG']['tl_repository']['okuninstextension']  = 'OK to uninstall <em>%s</em> now?';
$GLOBALS['TL_LANG']['tl_repository']['showdetails']        = 'Show details';
$GLOBALS['TL_LANG']['tl_repository']['stateshint']         = 'Check the states to be included.';
$GLOBALS['TL_LANG']['tl_repository']['status']             = 'Status';
$GLOBALS['TL_LANG']['tl_repository']['success']            = 'success';
$GLOBALS['TL_LANG']['tl_repository']['uninstallextension'] = 'Uninstall extension';
$GLOBALS['TL_LANG']['tl_repository']['updatedatabase']     = 'Check/update database';
$GLOBALS['TL_LANG']['tl_repository']['updateextension']    = 'Update extension';
$GLOBALS['TL_LANG']['tl_repository']['update']             = 'Update';
$GLOBALS['TL_LANG']['tl_repository']['updates']            = 'Updates';
$GLOBALS['TL_LANG']['tl_repository']['updatehint']         = 'Check the states to be included at updates.';
$GLOBALS['TL_LANG']['tl_repository']['updatingext']        = 'Update %s %s build %s';
$GLOBALS['TL_LANG']['tl_repository']['validate']           = 'Repair';
$GLOBALS['TL_LANG']['tl_repository']['validatingext']      = 'Verify/repair %s %s build %s';

/**
 * Status messages
 */
$GLOBALS['TL_LANG']['tl_repository_statext']['uptodate']        = 'Up to date.';
$GLOBALS['TL_LANG']['tl_repository_statext']['notapproved']     = 'Not approved for %s %s.';
$GLOBALS['TL_LANG']['tl_repository_statext']['notapprovedwith'] = 'Not approved with %s %s.';
$GLOBALS['TL_LANG']['tl_repository_statext']['newversion']      = 'New version %s build %s available.';
$GLOBALS['TL_LANG']['tl_repository_statext']['depmissing']      = 'Missing required extension %s.';
$GLOBALS['TL_LANG']['tl_repository_statext']['extnotfound']     = 'Extension not found in repository.';
$GLOBALS['TL_LANG']['tl_repository_statext']['vernotfound']     = 'Installed version not found in repository.';
$GLOBALS['TL_LANG']['tl_repository_statext']['extneedkey']      = 'License key required, install extension in advance.';
$GLOBALS['TL_LANG']['tl_repository_statext']['errorinstall']    = 'Failed installation, update/repair adviced.';

?>
